#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/11 17:00
Desc: 九期网-期货手续费
https://www.9qihuo.com/qihuoshouxufei
"""

from io import StringIO

import pandas as pd
import requests
from bs4 import BeautifulSoup


def _futures_comm_qihuo_process(df: pd.DataFrame, name: str = None) -> pd.DataFrame:
    """
    期货手续费数据细节处理函数
    https://www.9qihuo.com/qihuoshouxufei
    :param df: 获取到的 pandas.DataFrame 数据
    :type df: pandas.DataFrame
    :param name: 交易所名称
    :type name: str
    :return: 处理后的数据
    :rtype: pandas.DataFrame
    """
    import urllib3

    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
    common_temp_df = df.copy()
    common_temp_df["合约名称"] = (
        common_temp_df["合约品种"].str.split("(", expand=True).iloc[:, 0].str.strip()
    )
    common_temp_df["合约代码"] = (
        common_temp_df["合约品种"].str.split("(", expand=True).iloc[:, 1].str.strip(")")
    )
    common_temp_df["涨停板"] = (
        common_temp_df["涨/跌停板"].str.split("/", expand=True).iloc[:, 0].str.strip()
    )
    common_temp_df["跌停板"] = (
        common_temp_df["涨/跌停板"].str.split("/", expand=True).iloc[:, 1].str.strip()
    )
    common_temp_df["保证金-买开"] = common_temp_df["保证金-买开"].str.strip("%")
    common_temp_df["保证金-卖开"] = common_temp_df["保证金-卖开"].str.strip("%")
    common_temp_df["保证金-每手"] = common_temp_df["保证金-保证金/每手"].str.strip("元")
    common_temp_df["手续费"] = common_temp_df["手续费(开+平)"].str.strip("元")
    try:
        temp_df_ratio = (
            common_temp_df["手续费标准-开仓"][
                common_temp_df["手续费标准-开仓"].str.contains("万分之")
            ]
            .str.split("/", expand=True)
            .iloc[:, 0]
            .astype(float)
            / 10000
        )
    except IndexError:
        temp_df_ratio = pd.NA
    temp_df_yuan = common_temp_df["手续费标准-开仓"][
        common_temp_df["手续费标准-开仓"].str.contains("元")
    ]
    common_temp_df["手续费标准-开仓-万分之"] = temp_df_ratio
    common_temp_df["手续费标准-开仓-元"] = temp_df_yuan.str.strip("元")
    try:
        temp_df_ratio = (
            common_temp_df["手续费标准-平昨"][
                common_temp_df["手续费标准-平昨"].str.contains("万分之")
            ]
            .str.split("/", expand=True)
            .iloc[:, 0]
            .astype(float)
            / 10000
        )
    except IndexError:
        temp_df_ratio = pd.NA
    temp_df_yuan = common_temp_df["手续费标准-平昨"][
        common_temp_df["手续费标准-平昨"].str.contains("元")
    ]
    common_temp_df["手续费标准-平昨-万分之"] = temp_df_ratio
    common_temp_df["手续费标准-平昨-元"] = temp_df_yuan.str.strip("元")
    try:
        temp_df_ratio = (
            common_temp_df["手续费标准-平今"][
                common_temp_df["手续费标准-平今"].str.contains("万分之")
            ]
            .str.split("/", expand=True)
            .iloc[:, 0]
            .astype(float)
            / 10000
        )
    except IndexError:
        temp_df_ratio = pd.NA
    temp_df_yuan = common_temp_df["手续费标准-平今"][
        common_temp_df["手续费标准-平今"].str.contains("元")
    ]
    common_temp_df["手续费标准-平今-万分之"] = temp_df_ratio
    common_temp_df["手续费标准-平今-元"] = temp_df_yuan.str.strip("元")
    del common_temp_df["手续费标准-开仓"]
    del common_temp_df["手续费标准-平昨"]
    del common_temp_df["手续费标准-平今"]
    del common_temp_df["合约品种"]
    del common_temp_df["涨/跌停板"]
    del common_temp_df["手续费(开+平)"]
    del common_temp_df["保证金-保证金/每手"]
    common_temp_df["交易所名称"] = name
    common_temp_df = common_temp_df[
        [
            "交易所名称",
            "合约名称",
            "合约代码",
            "现价",
            "涨停板",
            "跌停板",
            "保证金-买开",
            "保证金-卖开",
            "保证金-每手",
            "手续费标准-开仓-万分之",
            "手续费标准-开仓-元",
            "手续费标准-平昨-万分之",
            "手续费标准-平昨-元",
            "手续费标准-平今-万分之",
            "手续费标准-平今-元",
            "每跳毛利",
            "手续费",
            "每跳净利",
            "备注",
        ]
    ]
    common_temp_df["现价"] = pd.to_numeric(common_temp_df["现价"])
    common_temp_df["涨停板"] = pd.to_numeric(common_temp_df["涨停板"])
    common_temp_df["跌停板"] = pd.to_numeric(common_temp_df["跌停板"])
    common_temp_df["保证金-买开"] = pd.to_numeric(common_temp_df["保证金-买开"])
    common_temp_df["保证金-卖开"] = pd.to_numeric(common_temp_df["保证金-卖开"])
    common_temp_df["保证金-每手"] = pd.to_numeric(common_temp_df["保证金-每手"])
    # common_temp_df["手续费标准-开仓-元"] = pd.to_numeric(common_temp_df["手续费标准-开仓-元"])
    # common_temp_df["手续费标准-平昨-元"] = pd.to_numeric(common_temp_df["手续费标准-平昨-元"])
    # common_temp_df["手续费标准-平今-元"] = pd.to_numeric(common_temp_df["手续费标准-平今-元"])
    common_temp_df["每跳毛利"] = pd.to_numeric(common_temp_df["每跳毛利"])
    common_temp_df["手续费"] = pd.to_numeric(common_temp_df["手续费"])
    common_temp_df["每跳净利"] = pd.to_numeric(common_temp_df["每跳净利"])
    url = "https://www.9qihuo.com/qihuoshouxufei"
    r = requests.get(url, verify=False)
    soup = BeautifulSoup(r.text, features="lxml")
    raw_date_text = soup.find(name="a", attrs={"id": "dlink"}).previous
    comm_update_time = raw_date_text.split("，")[0].strip("（手续费更新时间：")
    price_update_time = (
        raw_date_text.split("，")[1].strip("价格更新时间：").strip("。）")
    )
    common_temp_df["手续费更新时间"] = comm_update_time
    common_temp_df["价格更新时间"] = price_update_time
    return common_temp_df


def futures_comm_info(symbol: str = "所有") -> pd.DataFrame:
    """
    九期网-期货手续费
    https://www.9qihuo.com/qihuoshouxufei
    :param symbol: choice of {"所有", "上海期货交易所", "大连商品交易所", "郑州商品交易所", "上海国际能源交易中心", "中国金融期货交易所", "广州期货交易所"}
    :type symbol: str
    :return: 期货手续费
    :rtype: pandas.DataFrame
    """
    import urllib3

    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
    url = "https://www.9qihuo.com/qihuoshouxufei"
    r = requests.get(url, verify=False)
    temp_df = pd.read_html(StringIO(r.text))[0]
    temp_df.columns = [
        "合约品种",
        "现价",
        "涨/跌停板",
        "保证金-买开",
        "保证金-卖开",
        "保证金-保证金/每手",
        "手续费标准-开仓",
        "手续费标准-平昨",
        "手续费标准-平今",
        "每跳毛利",
        "手续费(开+平)",
        "每跳净利",
        "备注",
        "-",
        "-",
    ]
    df_0 = temp_df[temp_df["合约品种"].str.contains("上海期货交易所")].index.values[0]
    df_1 = temp_df[temp_df["合约品种"].str.contains("大连商品交易所")].index.values[0]
    df_2 = temp_df[temp_df["合约品种"].str.contains("郑州商品交易所")].index.values[0]
    df_3 = temp_df[
        temp_df["合约品种"].str.contains("上海国际能源交易中心")
    ].index.values[0]
    df_4 = temp_df[temp_df["合约品种"].str.contains("广州期货交易所")].index.values[0]
    df_5 = temp_df[temp_df["合约品种"].str.contains("中国金融期货交易所")].index.values[
        0
    ]
    shfe_df = temp_df.iloc[df_0 + 3 : df_1, :].reset_index(drop=True)
    dce_df = temp_df.iloc[df_1 + 3 : df_2, :].reset_index(drop=True)
    czce_df = temp_df.iloc[df_2 + 3 : df_3, :].reset_index(drop=True)
    ine_df = temp_df.iloc[df_3 + 3 : df_4, :].reset_index(drop=True)
    gfex_df = temp_df.iloc[df_4 + 3 : df_5, :].reset_index(drop=True)
    cffex_df = temp_df.iloc[df_5 + 3 :, :].reset_index(drop=True)
    if symbol == "上海期货交易所":
        return _futures_comm_qihuo_process(shfe_df, name="上海期货交易所")
    elif symbol == "大连商品交易所":
        return _futures_comm_qihuo_process(dce_df, name="大连商品交易所")
    elif symbol == "郑州商品交易所":
        return _futures_comm_qihuo_process(czce_df, name="郑州商品交易所")
    elif symbol == "上海国际能源交易中心":
        return _futures_comm_qihuo_process(ine_df, name="上海国际能源交易中心")
    elif symbol == "广州期货交易所":
        return _futures_comm_qihuo_process(gfex_df, name="广州期货交易所")
    elif symbol == "中国金融期货交易所":
        return _futures_comm_qihuo_process(cffex_df, name="中国金融期货交易所")
    else:
        big_df = pd.DataFrame()
        big_df = pd.concat(
            objs=[big_df, _futures_comm_qihuo_process(shfe_df, name="上海期货交易所")],
            ignore_index=True,
        )
        big_df = pd.concat(
            objs=[big_df, _futures_comm_qihuo_process(dce_df, name="大连商品交易所")],
            ignore_index=True,
        )
        big_df = pd.concat(
            objs=[big_df, _futures_comm_qihuo_process(czce_df, name="郑州商品交易所")],
            ignore_index=True,
        )
        big_df = pd.concat(
            objs=[
                big_df,
                _futures_comm_qihuo_process(ine_df, name="上海国际能源交易中心"),
            ],
            ignore_index=True,
        )
        big_df = pd.concat(
            objs=[big_df, _futures_comm_qihuo_process(gfex_df, name="广州期货交易所")],
            ignore_index=True,
        )
        big_df = pd.concat(
            objs=[
                big_df,
                _futures_comm_qihuo_process(cffex_df, name="中国金融期货交易所"),
            ],
            ignore_index=True,
        )
        return big_df


if __name__ == "__main__":
    futures_comm_info_df = futures_comm_info(symbol="所有")
    print(futures_comm_info_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/5/3 
Desc: 义乌小商品指数
目前可以通过这些接口直接请求到 JSON 数据
周价格指数：https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/history/piweek?gcCode=
月价格指数：https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/history/month?gcCode=
月景气指数：https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/history/bi?gcCode=
上涨：https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/get/rise
下跌：https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/get/drop
"""

import pandas as pd
import requests


def index_yw(symbol: str = "月景气指数") -> pd.DataFrame:
    """
    义乌小商品指数
    https://www.ywindex.com/Home/Product/index/
    :param symbol: choice of {"周价格指数", "月价格指数", "月景气指数"}
    :type symbol: str
    :return: 指数结果
    :rtype: pandas.DataFrame
    """
    import urllib3
    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

    if symbol == "月景气指数":
        url = "https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/history/bi?gcCode="
        r = requests.get(url, verify=False)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        temp_df = temp_df[["indextimeno", "totalindex", "scopeindex", "benifitindex", "confidentindex"]]
        temp_df.columns = ["期数", "景气指数", "规模指数", "效益指数", "市场信心指数"]
        temp_df["期数"] = pd.to_datetime(temp_df["期数"], errors="coerce").dt.date
        temp_df["景气指数"] = pd.to_numeric(temp_df["景气指数"], errors="coerce")
        temp_df["规模指数"] = pd.to_numeric(temp_df["规模指数"], errors="coerce")
        temp_df["效益指数"] = pd.to_numeric(temp_df["效益指数"], errors="coerce")
        temp_df["市场信心指数"] = pd.to_numeric(
            temp_df["市场信心指数"], errors="coerce"
        )
        temp_df.sort_values(["期数"], inplace=True, ignore_index=True)
        return temp_df
    else:
        symbol_map = {
            "周价格指数": "piweek",
            "月价格指数": "month"
        }
        url = f"https://apiserver.chinagoods.com/yiwuindex/v1/active/industry/class/history/{symbol_map[symbol]}?gcCode="
        r = requests.get(url, verify=False)
        data_json = r.json()
        columns_name = {
            "indextimeno": "期数",
            "totalpriceindex": "价格指数",
            "stockdealpriceindex": "场内价格指数",
            "netdealpriceindex": "网上价格指数",
            "orderdealpriceindex": "订单价格指数",
            "outdealpriceindex": "出口价格指数",
        }
        temp_df = pd.DataFrame(data_json["data"])
        temp_df.columns = [columns_name[name] for name in temp_df.columns]
        temp_df["期数"] = pd.to_datetime(temp_df["期数"], errors="coerce").dt.date
        temp_df["价格指数"] = pd.to_numeric(temp_df["价格指数"], errors="coerce")
        temp_df["场内价格指数"] = pd.to_numeric(
            temp_df["场内价格指数"], errors="coerce"
        )
        temp_df["网上价格指数"] = pd.to_numeric(
            temp_df["网上价格指数"], errors="coerce"
        )
        temp_df["订单价格指数"] = pd.to_numeric(
            temp_df["订单价格指数"], errors="coerce"
        )
        temp_df["出口价格指数"] = pd.to_numeric(
            temp_df["出口价格指数"], errors="coerce"
        )
        temp_df.sort_values(by=["期数"], inplace=True, ignore_index=True)
        return temp_df


if __name__ == "__main__":
    index_yw_df = index_yw(symbol="周价格指数")
    print(index_yw_df)

    index_yw_df = index_yw(symbol="月价格指数")
    print(index_yw_df)

    index_yw_df = index_yw(symbol="月景气指数")
    print(index_yw_df)
    



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/5/19 18:34
Desc: 巨潮资讯-数据中心-专题统计-公司治理-对外担保
https://webapi.cninfo.com.cn/#/thematicStatistics
"""

import pandas as pd
import requests
import py_mini_racer

from akshare.datasets import get_ths_js


def _get_file_content_ths(file: str = "cninfo.js") -> str:
    """
    获取 JS 文件的内容
    :param file:  JS 文件名
    :type file: str
    :return: 文件内容
    :rtype: str
    """
    setting_file_path = get_ths_js(file)
    with open(setting_file_path, encoding="utf-8") as f:
        file_data = f.read()
    return file_data


def stock_cg_guarantee_cninfo(
    symbol: str = "全部", start_date: str = "20180630", end_date: str = "20210927"
) -> pd.DataFrame:
    """
    巨潮资讯-数据中心-专题统计-公司治理-对外担保
    https://webapi.cninfo.com.cn/#/thematicStatistics
    :param symbol: choice of {"全部", "深市主板", "沪市", "创业板", "科创板"}
    :type symbol: str
    :param start_date: 开始统计时间
    :type start_date: str
    :param end_date: 结束统计时间
    :type end_date: str
    :return: 对外担保
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "全部": "",
        "深市主板": "012002",
        "沪市": "012001",
        "创业板": "012015",
        "科创板": "012029",
    }
    url = "https://webapi.cninfo.com.cn/api/sysapi/p_sysapi1054"
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_ths("cninfo.js")
    js_code.eval(js_content)
    mcode = js_code.call("getResCode1")
    headers = {
        "Accept": "*/*",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Content-Length": "0",
        "Host": "webapi.cninfo.com.cn",
        "Accept-Enckey": mcode,
        "Origin": "https://webapi.cninfo.com.cn",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "https://webapi.cninfo.com.cn/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/93.0.4577.63 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    params = {
        "sdate": "-".join([start_date[:4], start_date[4:6], start_date[6:]]),
        "edate": "-".join([end_date[:4], end_date[4:6], end_date[6:]]),
        "market": symbol_map[symbol],
    }
    r = requests.post(url, headers=headers, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["records"])
    temp_df.columns = [
        "公告统计区间",
        "担保金融占净资产比例",
        "担保金额",
        "担保笔数",
        "证券简称",
        "证券代码",
        "归属于母公司所有者权益",
    ]
    temp_df = temp_df[
        [
            "证券代码",
            "证券简称",
            "公告统计区间",
            "担保笔数",
            "担保金额",
            "归属于母公司所有者权益",
            "担保金融占净资产比例",
        ]
    ]
    temp_df["担保笔数"] = pd.to_numeric(temp_df["担保笔数"], errors="coerce")
    temp_df["担保金额"] = pd.to_numeric(temp_df["担保金额"], errors="coerce")
    temp_df["归属于母公司所有者权益"] = pd.to_numeric(
        temp_df["归属于母公司所有者权益"], errors="coerce"
    )
    temp_df["担保金融占净资产比例"] = pd.to_numeric(
        temp_df["担保金融占净资产比例"], errors="coerce"
    )
    return temp_df


if __name__ == "__main__":
    stock_corporate_governance_guarantee_df = stock_cg_guarantee_cninfo(
        symbol="全部", start_date="20180928", end_date="20210927"
    )
    print(stock_corporate_governance_guarantee_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/29 16:00
Desc: 日出和日落数据
https://www.timeanddate.com
"""

from io import StringIO

import pandas as pd
import requests


def sunrise_city_list() -> list:
    """
    查询日出与日落数据的城市列表
    https://www.timeanddate.com/astronomy/china
    :return: 所有可以获取的数据的城市列表
    :rtype: list
    """
    url = "https://www.timeanddate.com/astronomy/china"
    r = requests.get(url)
    city_list = []
    china_city_one_df = pd.read_html(StringIO(r.text))[1]
    china_city_two_df = pd.read_html(StringIO(r.text))[2]
    city_list.extend([item.lower() for item in china_city_one_df.iloc[:, 0].tolist()])
    city_list.extend([item.lower() for item in china_city_one_df.iloc[:, 3].tolist()])
    city_list.extend([item.lower() for item in china_city_one_df.iloc[:, 6].tolist()])
    city_list.extend([item.lower() for item in china_city_two_df.iloc[:, 0].tolist()])
    city_list.extend([item.lower() for item in china_city_two_df.iloc[:, 1].tolist()])
    city_list.extend([item.lower() for item in china_city_two_df.iloc[:, 2].tolist()])
    city_list.extend([item.lower() for item in china_city_two_df.iloc[:, 3].tolist()])
    city_list.extend(
        [item.lower() for item in china_city_two_df.iloc[:, 4].dropna().tolist()]
    )
    return city_list


def sunrise_daily(date: str = "20240428", city: str = "beijing") -> pd.DataFrame:
    """
    每日日出日落数据
    https://www.timeanddate.com/astronomy/china/shaoxing
    :param date: 需要查询的日期, e.g., “20200428”
    :type date: str
    :param city: 需要查询的城市; 注意输入的格式, e.g., "北京", "上海"
    :type city: str
    :return: 返回指定日期指定地区的日出日落数据
    :rtype: pandas.DataFrame
    """
    import urllib3

    urllib3.disable_warnings()
    if city in sunrise_city_list():
        year = date[:4]
        month = date[4:6]
        url = f"https://www.timeanddate.com/sun/china/{city}?month={month}&year={year}"
        r = requests.get(url, verify=False)
        table = pd.read_html(StringIO(r.text), header=2)[1]
        month_df = table.iloc[:-1,]
        day_df = month_df[
            month_df.iloc[:, 0].astype(str).str.zfill(2) == date[6:]
        ].copy()
        day_df.index = pd.to_datetime([date] * len(day_df), format="%Y%m%d")
        day_df.reset_index(inplace=True)
        day_df.rename(columns={"index": "date"}, inplace=True)
        day_df["date"] = pd.to_datetime(day_df["date"]).dt.date
        return day_df
    else:
        raise "请输入正确的城市名称"


def sunrise_monthly(date: str = "20240428", city: str = "beijing") -> pd.DataFrame:
    """
    每个指定 date 所在月份的每日日出日落数据, 如果当前月份未到月底, 则以预测值填充
    https://www.timeanddate.com/astronomy/china/shaoxing
    :param date: 需要查询的日期, 这里用来指定 date 所在的月份; e.g., “20200428”
    :type date: str
    :param city: 需要查询的城市; 注意输入的格式, e.g., "北京", "上海"
    :type city: str
    :return: 指定 date 所在月份的每日日出日落数据
    :rtype: pandas.DataFrame
    """
    import urllib3

    urllib3.disable_warnings()
    if city in sunrise_city_list():
        year = date[:4]
        month = date[4:6]
        url = f"https://www.timeanddate.com/sun/china/{city}?month={month}&year={year}"
        r = requests.get(url)
        table = pd.read_html(StringIO(r.text), header=2)[1]
        month_df = table.iloc[:-1,].copy()
        month_df.index = [date[:-2]] * len(month_df)
        month_df.reset_index(inplace=True)
        month_df.rename(
            columns={
                "index": "date",
            },
            inplace=True,
        )
        return month_df
    else:
        raise "请输入正确的城市名称"


if __name__ == "__main__":
    sunrise_daily_df = sunrise_daily(date="20240428", city="beijing")
    print(sunrise_daily_df)

    sunrise_monthly_df = sunrise_monthly(date="20240428", city="beijing")
    print(sunrise_monthly_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/2/11 20:32
Desc: 东方财富网-数据中心-重大合同-重大合同明细
https://data.eastmoney.com/zdht/mx.html
"""

import pandas as pd
import requests
from akshare.utils.tqdm import get_tqdm


def stock_zdhtmx_em(
    start_date: str = "20200819", end_date: str = "20230819"
) -> pd.DataFrame:
    """
    东方财富网-数据中心-重大合同-重大合同明细
    https://data.eastmoney.com/zdht/mx.html
    :param start_date: 开始日期, eg 20200819
    :type start_date: str
    :param end_date: 结束日期, eg 20230819
    :type end_date: str
    :return: 股东大会
    :rtype: pandas.DataFrame
    """
    import warnings

    warnings.filterwarnings(action="ignore", category=FutureWarning)
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "DIM_RDATE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "columns": "ALL",
        "token": "894050c76af8597a853f5b408b759f5d",
        "reportName": "RPTA_WEB_ZDHT_LIST",
        "filter": f"""(DIM_RDATE>='{"-".join([start_date[:4], start_date[4:6], start_date[6:]])}')
        (DIM_RDATE<='{"-".join([end_date[:4], end_date[4:6], end_date[6:]])}')""",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json["result"]["pages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update(
            {
                "pageNumber": page,
            }
        )
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        big_df = pd.concat(objs=[big_df, temp_df], axis=0, ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df["index"] = big_df["index"] + 1
    big_df.rename(
        columns={
            "index": "序号",
            "DIM_SCODE": "-",
            "CONTENTS": "-",
            "CONTRACTNAME": "合同名称",
            "CONTRACTTYPE": "-",
            "COUNTERPARTY": "其他签署方",
            "COUNTERPARTYREL": "-",
            "ISABOLISHED": "-",
            "DIM_RDATE": "公告日期",
            "REMARK": "-",
            "SIGNATORY": "签署主体",
            "SIGNATORYREL": "与上市公司关系",
            "SIGNDATE": "签署日期",
            "SIGNEFFECT": "-",
            "UPDATEDATE": "-",
            "YEAR": "-",
            "AMOUNTS": "合同金额",
            "SECURITYCODE": "股票代码",
            "SECURITYSHORTNAME": "股票简称",
            "CONTRACTTYPENAME": "合同类型",
            "SIGNATORYRELNAME": "签署主体-与上市公司关系",
            "COUNTERPARTYRELNAME": "其他签署方-与上市公司关系",
            "SNDYYSR": "上年度营业收入",
            "OPERATEREVE": "最新财务报表的营业收入",
            "RCHANGE1DC": "-",
            "RCHANGE20DC": "-",
            "ZSNDYYSRBL": "占上年度营业收入比例",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "序号",
            "股票代码",
            "股票简称",
            "签署主体",
            "签署主体-与上市公司关系",
            "其他签署方",
            "其他签署方-与上市公司关系",
            "合同类型",
            "合同名称",
            "合同金额",
            "上年度营业收入",
            "占上年度营业收入比例",
            "最新财务报表的营业收入",
            "签署日期",
            "公告日期",
        ]
    ]
    big_df["签署日期"] = pd.to_datetime(big_df["签署日期"], errors="coerce").dt.date
    big_df["公告日期"] = pd.to_datetime(big_df["公告日期"], errors="coerce").dt.date
    big_df["合同金额"] = pd.to_numeric(big_df["合同金额"], errors="coerce")
    big_df["上年度营业收入"] = pd.to_numeric(big_df["上年度营业收入"], errors="coerce")
    big_df["占上年度营业收入比例"] = pd.to_numeric(
        big_df["占上年度营业收入比例"], errors="coerce"
    )
    big_df["最新财务报表的营业收入"] = pd.to_numeric(
        big_df["最新财务报表的营业收入"], errors="coerce"
    )
    return big_df


if __name__ == "__main__":
    stock_zdhtmx_em_df = stock_zdhtmx_em(start_date="20220819", end_date="20230819")
    print(stock_zdhtmx_em_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2024/4/29 17:00
Desc: 人民币汇率中间价
https://www.safe.gov.cn/safe/rmbhlzjj/index.html
"""

import re
from datetime import datetime
from io import StringIO

import pandas as pd
import requests
from bs4 import BeautifulSoup


def currency_boc_safe() -> pd.DataFrame:
    """
    人民币汇率中间价
    https://www.safe.gov.cn/safe/rmbhlzjj/index.html
    :return: 人民币汇率中间价
    :rtype: pandas.DataFrame
    """
    url = "https://www.safe.gov.cn/safe/2020/1218/17833.html"
    r = requests.get(url)
    r.encoding = "utf8"
    soup = BeautifulSoup(r.text, features="lxml")
    content = soup.find(name="a", string=re.compile("人民币汇率"))["href"]
    url = f"https://www.safe.gov.cn{content}"
    temp_df = pd.read_excel(url)
    temp_df.sort_values(by=["日期"], inplace=True)
    temp_df.reset_index(inplace=True, drop=True)
    start_date = (
        (pd.Timestamp(temp_df["日期"].tolist()[-1]) + pd.Timedelta(days=1))
        .isoformat()
        .split("T")[0]
    )
    end_date = datetime.now().isoformat().split("T")[0]
    url = "https://www.safe.gov.cn/AppStructured/hlw/RMBQuery.do"
    payload = {
        "startDate": start_date,
        "endDate": end_date,
        "queryYN": "true",
    }
    r = requests.post(url, data=payload)
    current_temp_df = pd.read_html(StringIO(r.text))[-1]
    current_temp_df.sort_values(by=["日期"], inplace=True)
    current_temp_df.reset_index(inplace=True, drop=True)
    big_df = pd.concat(objs=[temp_df, current_temp_df], ignore_index=True)
    column_name_list = big_df.columns[1:]
    for item in column_name_list:
        big_df[item] = pd.to_numeric(big_df[item], errors="coerce")
    big_df["日期"] = pd.to_datetime(big_df["日期"], errors="coerce").dt.date
    return big_df


if __name__ == "__main__":
    currency_boc_safe_df = currency_boc_safe()
    print(currency_boc_safe_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2025/2/15 22:00
Desc: 东方财富网-个股-股票信息
https://quote.eastmoney.com/concept/sh603777.html?from=classic
"""

import pandas as pd
import requests


def stock_individual_info_em(
    symbol: str = "603777", timeout: float = None
) -> pd.DataFrame:
    """
    东方财富-个股-股票信息
    https://quote.eastmoney.com/concept/sh603777.html?from=classic
    :param symbol: 股票代码
    :type symbol: str
    :param timeout: choice of None or a positive float number
    :type timeout: float
    :return: 股票信息
    :rtype: pandas.DataFrame
    """
    url = "https://push2.eastmoney.com/api/qt/stock/get"
    market_code = 1 if symbol.startswith("6") else 0
    params = {
        "fltt": "2",
        "invt": "2",
        "fields": "f120,f121,f122,f174,f175,f59,f163,f43,f57,f58,f169,f170,f46,f44,f51,f168,f47,"
        "f164,f116,f60,f45,f52,f50,f48,f167,f117,f71,f161,f49,f530,f135,f136,f137,f138,"
        "f139,f141,f142,f144,f145,f147,f148,f140,f143,f146,f149,f55,f62,f162,f92,f173,f104,"
        "f105,f84,f85,f183,f184,f185,f186,f187,f188,f189,f190,f191,f192,f107,f111,f86,f177,f78,"
        "f110,f262,f263,f264,f267,f268,f255,f256,f257,f258,f127,f199,f128,f198,f259,f260,f261,"
        "f171,f277,f278,f279,f288,f152,f250,f251,f252,f253,f254,f269,f270,f271,f272,f273,f274,"
        "f275,f276,f265,f266,f289,f290,f286,f285,f292,f293,f294,f295,f43",
        "secid": f"{market_code}.{symbol}",
    }
    r = requests.get(url, params=params, timeout=timeout)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json)
    temp_df.reset_index(inplace=True)
    del temp_df["rc"]
    del temp_df["rt"]
    del temp_df["svr"]
    del temp_df["lt"]
    del temp_df["full"]
    code_name_map = {
        "f57": "股票代码",
        "f58": "股票简称",
        "f84": "总股本",
        "f85": "流通股",
        "f127": "行业",
        "f116": "总市值",
        "f117": "流通市值",
        "f189": "上市时间",
        "f43": "最新",
    }
    temp_df["index"] = temp_df["index"].map(code_name_map)
    temp_df = temp_df[pd.notna(temp_df["index"])]
    if "dlmkts" in temp_df.columns:
        del temp_df["dlmkts"]
    temp_df.columns = [
        "item",
        "value",
    ]
    temp_df.reset_index(inplace=True, drop=True)
    return temp_df


if __name__ == "__main__":
    stock_individual_info_em_df = stock_individual_info_em(symbol="000002")
    print(stock_individual_info_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/30 10:30
Desc: 破净股统计历史走势
https://www.legulegu.com/stockdata/below-net-asset-statistics
"""

import pandas as pd
import requests

from akshare.utils.cons import headers


def stock_a_below_net_asset_statistics(symbol: str = "全部A股") -> pd.DataFrame:
    """
    破净股统计历史走势
    https://www.legulegu.com/stockdata/below-net-asset-statistics
    :param symbol: choice of {"全部A股", "沪深300", "上证50", "中证500"}
    :type symbol: str
    :return: 破净股统计历史走势
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "全部A股": "1",
        "沪深300": "000300.XSHG",
        "上证50": "000016.SH",
        "中证500": "000905.SH",
    }
    url = "https://legulegu.com/stockdata/below-net-asset-statistics-data"
    params = {
        "marketId": symbol_map[symbol],
        "token": "325843825a2745a2a8f9b9e3355cb864",
    }
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json)
    temp_df["date"] = pd.to_datetime(temp_df["date"], unit="ms").dt.date
    del temp_df["marketId"]
    big_df = temp_df.iloc[:, :3]
    big_df.columns = ["below_net_asset", "total_company", "date"]
    big_df["below_net_asset_ratio"] = round(
        big_df["below_net_asset"] / big_df["total_company"], 4
    )
    big_df = big_df[
        ["date", "below_net_asset", "total_company", "below_net_asset_ratio"]
    ]
    big_df["date"] = pd.to_datetime(big_df["date"], errors="coerce").dt.date
    big_df["below_net_asset"] = pd.to_numeric(
        big_df["below_net_asset"], errors="coerce"
    )
    big_df["total_company"] = pd.to_numeric(big_df["total_company"], errors="coerce")
    big_df["below_net_asset_ratio"] = pd.to_numeric(
        big_df["below_net_asset_ratio"], errors="coerce"
    )
    big_df.sort_values(["date"], inplace=True, ignore_index=True)
    return big_df


if __name__ == "__main__":
    stock_a_below_net_asset_statistics_df = stock_a_below_net_asset_statistics(
        symbol="全部A股"
    )
    print(stock_a_below_net_asset_statistics_df)

    stock_a_below_net_asset_statistics_df = stock_a_below_net_asset_statistics(
        symbol="沪深300"
    )
    print(stock_a_below_net_asset_statistics_df)

    stock_a_below_net_asset_statistics_df = stock_a_below_net_asset_statistics(
        symbol="上证50"
    )
    print(stock_a_below_net_asset_statistics_df)

    stock_a_below_net_asset_statistics_df = stock_a_below_net_asset_statistics(
        symbol="中证500"
    )
    print(stock_a_below_net_asset_statistics_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2020/2/13 21:22
Desc: 存储和读取 Token 文件
"""

import os

import pandas as pd

from akshare.pro import cons


def set_token(token):
    df = pd.DataFrame([token], columns=["token"])
    user_home = os.path.expanduser("~")
    fp = os.path.join(user_home, cons.TOKEN_F_P)
    df.to_csv(fp, index=False)


def get_token():
    user_home = os.path.expanduser("~")
    fp = os.path.join(user_home, cons.TOKEN_F_P)
    if os.path.exists(fp):
        df = pd.read_csv(fp)
        return str(df.iloc[0]["token"])
    else:
        print(cons.TOKEN_ERR_MSG)
        return


if __name__ == "__main__":
    pass



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/4/10 18:00
Desc: 奇货可查网站目前已经商业化运营, 特提供奇货可查-指数数据接口, 方便您程序化调用
注：期货价格为收盘价; 现货价格来自网络; 基差=现货价格-期货价格; 基差率=(现货价格-期货价格)/现货价格 * 100 %.
"""

from typing import AnyStr

import pandas as pd
import requests

from akshare.futures.cons import (
    QHKC_INDEX_URL,
    QHKC_INDEX_TREND_URL,
    QHKC_INDEX_PROFIT_LOSS_URL,
)


def get_qhkc_index(name: AnyStr = "奇货商品", url: AnyStr = QHKC_INDEX_URL):
    """
    奇货可查-指数-指数详情
    获得奇货可查的指数数据: '奇货黑链', '奇货商品', '奇货谷物', '奇货贵金属', '奇货饲料', '奇货软商品', '奇货化工', '奇货有色', '奇货股指', '奇货铁合金', '奇货油脂'
    :param url: 网址
    :type url: str
    :param name: 中文名称
    :type name: str
    :return: 指数详情
    :rtype: pandas.DataFrame
        date    price   volume  ...      margin     profit long_short_ratio
        2013-01-04     1000   260820  ...  1130485758    1816940            52.78
        2013-01-07  998.244   245112  ...  1132228518    2514410            52.15
        2013-01-08   1000.8   318866  ...  1160374489    2981010            51.99
        2013-01-09  998.661   247352  ...  1166611242    3904220            52.44
        2013-01-10  999.802   161292  ...  1153164771    1448190            52.81
               ...      ...      ...  ...         ...        ...              ...
        2019-09-24  845.391   881138  ...  1895149977  128379050             48.5
        2019-09-25  845.674   715180  ...  1797235248  128788230            48.29
        2019-09-26  840.154  1347570  ...  1730488227  137104890            48.44
        2019-09-27  834.831   920160  ...  1605342767  143128540            48.77
        2019-09-30  831.959  1031558  ...  1521875378  147810580            48.82
    """
    name_id_dict = {}
    qhkc_index_url = "https://qhkch.com/ajax/official_indexes.php"
    r = requests.post(qhkc_index_url)
    display_name = [item["name"] for item in r.json()["data"]]
    index_id = [item["id"] for item in r.json()["data"]]
    for item in range(len(display_name)):
        name_id_dict[display_name[item]] = index_id[item]
    payload_id = {"id": name_id_dict[name]}
    r = requests.post(url, data=payload_id)
    print(name, "数据获取成功")
    json_data = r.json()
    date = json_data["data"]["date"]
    price = json_data["data"]["price"]
    volume = json_data["data"]["volume"]
    open_interest = json_data["data"]["openint"]
    total_value = json_data["data"]["total_value"]
    profit = json_data["data"]["profit"]
    long_short_ratio = json_data["data"]["line"]
    df_temp = pd.DataFrame(
        [date, price, volume, open_interest, total_value, profit, long_short_ratio]
    ).T
    df_temp.columns = [
        "date",
        "price",
        "volume",
        "open_interest",
        "margin",
        "profit",
        "long_short_ratio",
    ]
    return df_temp


def get_qhkc_index_trend(name: AnyStr = "奇货商品", url: AnyStr = QHKC_INDEX_TREND_URL):
    """
    奇货可查-指数-大资金动向
    获得奇货可查的指数数据: '奇货黑链', '奇货商品', '奇货谷物', '奇货贵金属', '奇货饲料', '奇货软商品', '奇货化工', '奇货有色', '奇货股指', '奇货铁合金', '奇货油脂'
    :param name: None
    :type name: str
    :param url: 网址
    :type url: str
    :return: 大资金动向
    :rtype: pandas.DataFrame
        broker    grade    money     open_order     variety
        中金期货     B -3.68209e+07  3.68209e+07      沪金
        浙商期货     D    -25845534     25845534      沪银
        永安期货     A    -25614000     25614000      沪银
        招商期货     D    -23517351     23517351      沪银
        海通期货     A     21440845     21440845      沪金
         美尔雅     D     21370975     21370975      沪金
        中原期货     C    -21204612     21204612      沪银
        国投安信     A -1.52374e+07  1.52374e+07      沪银
        中信期货     C  1.50941e+07  1.50941e+07      沪银
        海通期货     A -1.47184e+07  1.47184e+07      沪银
        方正中期     E -1.31432e+07  1.31432e+07      沪银
        东证期货     D   -1.283e+07    1.283e+07      沪银
        一德期货     A  1.24973e+07  1.24973e+07      沪银
        国投安信     A    -11602860     11602860      沪金
        国泰君安     B -1.09363e+07  1.09363e+07      沪金
        华安期货     D -9.99499e+06  9.99499e+06      沪金
        南华期货     B -9.23675e+06  9.23675e+06      沪银
        国贸期货     B  8.55245e+06  8.55245e+06      沪银
        道通期货     C      8527675      8527675      沪金
        招商期货     D -7.85457e+06  7.85457e+06      沪金
        东方财富     E -7.58235e+06  7.58235e+06      沪银
        五矿经易     A  6.95354e+06  6.95354e+06      沪银
        银河期货     B  6.84522e+06  6.84522e+06      沪银
        国贸期货     B      6731025      6731025      沪金
        平安期货     D     -6710418      6710418      沪银
        上海中期     C      6628800      6628800      沪金
        中信期货     C     -6345830      6345830      沪金
        银河期货     B     -6126295      6126295      沪金
        华泰期货     A -5.96254e+06  5.96254e+06      沪金
        招金期货     E -5.53029e+06  5.53029e+06      沪银
        东证期货     D -5.47486e+06  5.47486e+06      沪金
        光大期货     C     -5334730      5334730      沪金
        广发期货     D  5.31904e+06  5.31904e+06      沪金
        国信期货     D -5.05211e+06  5.05211e+06      沪金
    """
    name_id_dict = {}
    qhkc_index_url = "https://qhkch.com/ajax/official_indexes.php"
    r = requests.post(qhkc_index_url)
    display_name = [item["name"] for item in r.json()["data"]]
    index_id = [item["id"] for item in r.json()["data"]]
    for item in range(len(display_name)):
        name_id_dict[display_name[item]] = index_id[item]
    payload_id = {"page": 1, "limit": 10, "index": name_id_dict[name], "date": ""}
    r = requests.post(url, data=payload_id)
    print(f"{name}期货指数-大资金动向数据获取成功")
    json_data = r.json()
    df_temp = pd.DataFrame()
    for item in json_data["data"]:
        broker = item["broker"]
        grade = item["grade"]
        money = item["money"]
        order_money = item["order_money"]
        variety = item["variety"]
        df_temp = df_temp._append(
            pd.DataFrame([broker, grade, money, order_money, variety]).T
        )
    df_temp.columns = ["broker", "grade", "money", "open_order", "variety"]
    df_temp.reset_index(drop=True, inplace=True)
    return df_temp


def get_qhkc_index_profit_loss(
    name: AnyStr = "奇货商品",
    url: AnyStr = QHKC_INDEX_PROFIT_LOSS_URL,
    start_date="",
    end_date="",
):
    """
    奇货可查-指数-盈亏详情
    获得奇货可查的指数数据: '奇货黑链', '奇货商品', '奇货谷物', '奇货贵金属', '奇货饲料', '奇货软商品', '奇货化工', '奇货有色', '奇货股指', '奇货铁合金', '奇货油脂'
    :param url: 网址
    :type url: str
    :param name: None
    :type name: str
    :param start_date: ""
    :type start_date: str
    :param end_date: "20190716" 指定 end_date 就可以了
    :type end_date: str
    :return: 盈亏详情
    :rtype: pandas.DataFrame
        indexes       value  trans_date
        招金期货-沪金  -307489200  2019-09-30
        平安期货-沪银  -195016650  2019-09-30
        建信期货-沪银  -160327350  2019-09-30
        国贸期货-沪银  -159820965  2019-09-30
        东证期货-沪银  -123508635  2019-09-30
            ...         ...         ...
        永安期货-沪银   187411350  2019-09-30
        中信期货-沪金   242699750  2019-09-30
        华泰期货-沪银   255766185  2019-09-30
        永安期货-沪金   293008700  2019-09-30
        国泰君安-沪金   302774950  2019-09-30
    """
    name_id_dict = {}
    qhkc_index_url = "https://qhkch.com/ajax/official_indexes.php"
    r = requests.post(qhkc_index_url)
    display_name = [item["name"] for item in r.json()["data"]]
    index_id = [item["id"] for item in r.json()["data"]]
    for item in range(len(display_name)):
        name_id_dict[display_name[item]] = index_id[item]
    payload_id = {"index": name_id_dict[name], "date1": start_date, "date2": end_date}
    r = requests.post(url, data=payload_id)
    print(f"{name}期货指数-盈亏分布数据获取成功")
    json_data = r.json()
    indexes = json_data["data"]["indexes"]
    value = json_data["data"]["value"]
    trans_date = [json_data["data"]["trans_date"]] * len(value)
    df_temp = pd.DataFrame([indexes, value, trans_date]).T
    df_temp.columns = ["indexes", "value", "trans_date"]
    return df_temp


if __name__ == "__main__":
    get_qhkc_index_df = get_qhkc_index("奇货谷物")
    print(get_qhkc_index_df)

    get_qhkc_index_trend_df = get_qhkc_index_trend("奇货贵金属")
    print(get_qhkc_index_trend_df)

    get_qhkc_index_profit_loss_df = get_qhkc_index_profit_loss("奇货贵金属", end_date="20250410")
    print(get_qhkc_index_profit_loss_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2023/11/15 18:00
Desc: 东方财富网-数据中心-期货期权-COMEX库存数据
https://data.eastmoney.com/pmetal/comex/by.html
"""

import pandas as pd
import requests

from akshare.utils.tqdm import get_tqdm


def futures_comex_inventory(symbol: str = "黄金") -> pd.DataFrame:
    """
    东方财富网-数据中心-期货期权-COMEX库存数据
    https://data.eastmoney.com/pmetal/comex/by.html
    :param symbol: choice of {"黄金", "白银"}
    :type symbol: str
    :return: COMEX库存数据
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "黄金": "EMI00069026",
        "白银": "EMI00069027",
    }
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "REPORT_DATE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "reportName": "RPT_FUTUOPT_GOLDSIL",
        "columns": "ALL",
        "quoteColumns": "",
        "source": "WEB",
        "client": "WEB",
        "filter": f'(INDICATOR_ID1="{symbol_map[symbol]}")(@STORAGE_TON<>"NULL")',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json["result"]["pages"]
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update(
            {
                "pageNumber": page,
            }
        )
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        big_df = pd.concat(objs=[big_df, temp_df], axis=0, ignore_index=True)

    big_df.reset_index(inplace=True)
    big_df["index"] = big_df["index"] + 1
    big_df.rename(
        columns={
            "index": "序号",
            "REPORT_DATE": "日期",
            "INDICATOR_NAME": "-",
            "INDICATOR_ID1": "-",
            "STORAGE_TON": f"COMEX{symbol}库存量-吨",
            "STORAGE_OUNCE": f"COMEX{symbol}库存量-盎司",
            "INDICATOR_ID2": "-",
            "NETPOSITION_TON": "-",
            "NETPOSITION_OUNCE": "-",
            "NETPOSITION_DOLLAR": "-",
            "INDICATOR_ID3": "-",
            "OPENPOSI_STOCK": "-",
            "OPENPOSTOCK_WECHANGE": "-",
            "OPENPOSI_STOCK_SUM": "-",
        },
        inplace=True,
    )
    big_df = big_df[
        [
            "序号",
            "日期",
            f"COMEX{symbol}库存量-吨",
            f"COMEX{symbol}库存量-盎司",
        ]
    ]
    big_df[f"COMEX{symbol}库存量-吨"] = pd.to_numeric(
        big_df[f"COMEX{symbol}库存量-吨"], errors="coerce"
    )
    big_df[f"COMEX{symbol}库存量-盎司"] = pd.to_numeric(
        big_df[f"COMEX{symbol}库存量-盎司"], errors="coerce"
    )
    big_df["日期"] = pd.to_datetime(big_df["日期"], errors="coerce").dt.date
    big_df.sort_values(["日期"], inplace=True, ignore_index=True)
    big_df["序号"] = range(1, len(big_df) + 1)
    return big_df


if __name__ == "__main__":
    futures_comex_inventory_df = futures_comex_inventory(symbol="黄金")
    print(futures_comex_inventory_df)
